<img src="http://salvushub.github.io/pyexodus/_static/logo.svg" width="250">

[![Build Status](https://travis-ci.org/SalvusHub/pyexodus.svg?branch=master)](https://travis-ci.org/SalvusHub/pyexodus) [![codecov](https://codecov.io/gh/SalvusHub/pyexodus/branch/master/graph/badge.svg)](https://codecov.io/gh/SalvusHub/pyexodus) [![license](https://img.shields.io/badge/license-MIT-F57F17.svg)](https://opensource.org/licenses/MIT) [![python-version](https://img.shields.io/badge/python-3.6,3.7,3.8-blue.svg)](http://python.org)
[![OS-support](https://img.shields.io/badge/OS-linux,win,osx-850A8B.svg)](https://github.com/SalvusHub/pyexodus)

**Documentation:** https://salvushub.github.io/pyexodus/

---

The [MeshIO](https://github.com/nschloe/meshio) package is much more feature complete and likely a better fit for most purposes.

---

Pure Python (still requires h5py and numpy) package to write exodus files. It
emulates the Python API of the official Python exodus wrapper but is much much
easier to get going.

Don't expect this to be complete anytime soon - we will add stuff as soon as we
need it.
